pub struct WinitSettings {
pub focused_mode: UpdateMode,
pub unfocused_mode: UpdateMode,
}Expand description
Settings for the WinitPlugin.
Fields
focused_mode: UpdateModeDetermines how frequently the application can update when it has focus.
unfocused_mode: UpdateModeDetermines how frequently the application can update when it’s out of focus.
Implementations
Sourceimpl WinitSettings
impl WinitSettings
Sourcepub fn game() -> WinitSettings
pub fn game() -> WinitSettings
Default settings for games.
Continuous if windows have focus,
reactive_low_power otherwise.
Sourcepub fn desktop_app() -> WinitSettings
pub fn desktop_app() -> WinitSettings
Default settings for desktop applications.
Reactive if windows have focus,
reactive_low_power otherwise.
Use the EventLoopProxy to request a redraw from outside bevy.
Sourcepub fn mobile() -> WinitSettings
pub fn mobile() -> WinitSettings
Default settings for mobile.
Reactive if windows have focus,
reactive_low_power otherwise.
Use the EventLoopProxy to request a redraw from outside bevy.
Sourcepub fn continuous() -> WinitSettings
pub fn continuous() -> WinitSettings
The application will update as fast possible.
Uses Continuous regardless of whether windows have focus.
Sourcepub fn update_mode(&self, focused: bool) -> UpdateMode
pub fn update_mode(&self, focused: bool) -> UpdateMode
Returns the current UpdateMode.
Note: The output depends on whether the window has focus or not.